import {
  faArrowUpRightFromSquare,
  faBookOpen,
  faHashtag,
} from "@fortawesome/pro-regular-svg-icons";
import { JSXElement, Show, createMemo } from "solid-js";
import { A } from "solid-start";
import { FontAwesomeIcon } from "./FontAwesomeIcon";

const types = {
  external: faArrowUpRightFromSquare,
  page: faBookOpen,
  id: faHashtag,
};

/**
 * References to local and external resouces
 */
function R(props: {
  href: string;
  children: JSXElement;
  class?: string;
  id?: string;
}) {
  const type = createMemo((): keyof typeof types => {
    switch (true) {
      case props.href.startsWith("http"):
        return "external";
      case props.href.startsWith("#"):
        return "id";
      case props.href.startsWith("/"):
        return "page";
      default:
        console.warn("StartsWith is unknown:", props.href);
        return "external";
    }
  });
  return (
    <>
      {" "}
      <A
        href={props.href}
        target={type() === "external" ? "_blank" : ""}
        rel={type() === "external" ? "noreferrer noopener" : ""}
        id={props.id}
        class={props.class}
      >
        <Show when={type() === "id"}>
          <FontAwesomeIcon class="left" icon={types["id"]} />
        </Show>
        {props.children}
        <Show when={type() !== "id"}>
          <FontAwesomeIcon class="right" icon={types[type()]} title={type()} />
        </Show>
      </A>{" "}
    </>
  );
}

export default R;
