import {
  faBookOpen,
  faCircleHalfStroke,
  faGlobe,
  faXmark,
} from "@fortawesome/pro-regular-svg-icons";
import { createSignal } from "solid-js";
import { A, useLocation, useNavigate } from "solid-start";
import { FontAwesomeIcon } from "../FontAwesomeIcon";

export const [lightMode, setLightMode] = createSignal(false);
const [menu, setMenu] = createSignal(false);

function Navbar() {
  const navigate = useNavigate();
  const location = useLocation();
  return (
    <>
      <div id="navbar" style={{ visibility: menu() ? "visible" : "hidden" }}>
        <A href="/de/">
          <FontAwesomeIcon icon={faBookOpen} /> Einführung
        </A>

        <A href="/de/overview">
          <FontAwesomeIcon icon={faBookOpen} /> Start
        </A>
        <ol>
          <li>
            <A href="/de/overview#start">Was sind EUCs?</A>
          </li>
          <li>
            <A href="/de/overview#why">Warum EUCs?</A>
          </li>
          <li>
            <A href="/de/overview#funktion">Funktionsweise</A>
          </li>
          <li>
            <A href="/de/overview#begriffe">Begriffe</A>
          </li>
          <li>
            <A href="/de/overview#sicherheit">Sicherheit</A>
          </li>
          <li>
            <A href="/de/overview#ausrüstung">Ausrüstung</A>
          </li>
          <li>
            <A href="/de/overview#cutout">Cut-out's</A>
          </li>
          <li>
            <A href="/de/overview#akkuss">Akkusicherheit</A>
          </li>
          <li>
            <A href="/de/overview#fahrweise">Fahrweise</A>
          </li>
          <li>
            <A href="/de/overview#wobbles">Wobbles</A>
          </li>
          <li>
            <A href="/de/overview#leistung">Leistung</A>
          </li>
          <li>
            <A href="/de/overview#federung">Federung</A>
          </li>
          <li>
            <A href="/de/overview#reifen">Reifen</A>
          </li>
          <li>
            <A href="/de/overview#historie">Historie</A>
          </li>
          <li>
            <A href="/de/overview#geräte">Geräte Liste</A>
          </li>
        </ol>

        <A href="/de/manufacturers">
          <FontAwesomeIcon icon={faBookOpen} /> Hersteller
        </A>

        <button onClick={() => setLightMode((e) => !e)}>
          {lightMode() ? "Dark Mode " : "Light Mode "}
          <FontAwesomeIcon icon={faCircleHalfStroke} />
        </button>
        <button
          onClick={() => {
            navigate("/en" + location.pathname.slice(3), { scroll: false });
            setMenu(false);
          }}
        >
          Englisch <FontAwesomeIcon icon={faGlobe} />
        </button>
        <button onClick={() => setMenu(false)}>
          Close <FontAwesomeIcon icon={faXmark} />
        </button>
      </div>

      <div
        id="sidenavbar"
        style={{ visibility: menu() ? "hidden" : "visible" }}
      >
        <button onClick={() => navigate(-1)}>Zurück</button>
        <button onClick={() => navigate("/de/overview")}>Start</button>
        <button onClick={() => setMenu(true)}>Menu</button>
      </div>
    </>
  );
}

export default Navbar;
